summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--doc/src/s60-introduction.qdoc20
-rw-r--r--doc/src/snippets/code/doc_src_installation.qdoc4
-rw-r--r--doc/src/snippets/code/doc_src_s60-introduction.qdoc12
-rw-r--r--mkspecs/symbian-sbsv2/flm/qt/qmake_store_build.flm4
-rw-r--r--qmake/generators/symbian/symmake.cpp38
-rw-r--r--qmake/generators/symbian/symmake.h2
-rw-r--r--qmake/generators/symbian/symmake_abld.cpp8
-rw-r--r--qmake/generators/symbian/symmake_sbsv2.cpp2
8 files changed, 45 insertions, 45 deletions
diff --git a/doc/src/s60-introduction.qdoc b/doc/src/s60-introduction.qdoc
index 53ad562..0fd3a30 100644
--- a/doc/src/s60-introduction.qdoc
+++ b/doc/src/s60-introduction.qdoc
@@ -90,7 +90,7 @@
\row \o \c debug-armv5 \o Build debug binaries for hardware using RVCT.
\row \o \c release-armv5 \o Build release binaries for hardware using RVCT.
\row \o \c run \o Run the emulator binaries from the build directory.
- \row \o \c sisx \o Create signed \c .sis file for project.
+ \row \o \c sis \o Create signed \c .sis file for project.
\endtable
The following lines perform a debug build for the emulator
@@ -104,9 +104,9 @@
\section1 Installing your own applications
To install your own applications on hardware, you need signed \c .sis file.
- The signed \c .sis file can be created with \c make \c sisx target. \c sisx target
+ The signed \c .sis file can be created with \c make \c sis target. \c sis target
is only supported for executables or projects with \c DEPLOYMENT statements.
- By default the \c sisx target will create signed \.sis file for last build
+ By default the \c sis target will create signed \.sis file for last build
target. For example, the following sequence will generate the needed makefiles,
build the project for \c debug-winscw and \c release-armv5, and create
self-signed \c .sis file for \c release-armv5 target:
@@ -118,18 +118,18 @@
shown in the table below:
\table
- \row \o \c QT_SISX_OPTIONS \o Options accepted by \c .sis creation.
+ \row \o \c QT_SIS_OPTIONS \o Options accepted by \c .sis creation.
Currently only -i, install the package right away
using PC suite, is supported.
By default no otions are given.
- \row \o \c QT_SISX_TARGET \o Target for which \c .sis file is created.
+ \row \o \c QT_SIS_TARGET \o Target for which \c .sis file is created.
Accepted values are build targets listed in
previous table. By default last build target.
- \row \o \c QT_SISX_CERTIFICATE \o The certificate file used for signing.
+ \row \o \c QT_SIS_CERTIFICATE \o The certificate file used for signing.
By default self-signed certificate.
- \row \o \c QT_SISX_KEY \o The certificate's private key file.
+ \row \o \c QT_SIS_KEY \o The certificate's private key file.
By default key is associated to self-signed certificate.
- \row \o \c QT_SISX_PASSPHRASE \o The certificate's private key file's passphrase.
+ \row \o \c QT_SIS_PASSPHRASE \o The certificate's private key file's passphrase.
By default empty.
\endtable
@@ -142,8 +142,8 @@
\snippet doc/src/snippets/code/doc_src_s60-introduction.qdoc 4
If you want to install the program immediately, make sure that the device
- is connected to the computer in "PC Suite" mode, and run \c sisx target
- with the \c QT_SISX_OPTIONS=-i, like this:
+ is connected to the computer in "PC Suite" mode, and run \c sis target
+ with the \c QT_SIS_OPTIONS=-i, like this:
\snippet doc/src/snippets/code/doc_src_s60-introduction.qdoc 5
*/
diff --git a/doc/src/snippets/code/doc_src_installation.qdoc b/doc/src/snippets/code/doc_src_installation.qdoc
index e84e188..e294c12 100644
--- a/doc/src/snippets/code/doc_src_installation.qdoc
+++ b/doc/src/snippets/code/doc_src_installation.qdoc
@@ -197,10 +197,10 @@ make release-armv5
//! [29]
cd src\s60installs
-make sisx QT_SISX_OPTIONS=-i QT_SISX_CERTIFICATE=<certificate file> QT_SISX_KEY=<certificate key file>
+make sis QT_SIS_OPTIONS=-i QT_SIS_CERTIFICATE=<certificate file> QT_SIS_KEY=<certificate key file>
//! [29]
//! [30]
cd embedded\fluidlauncher
-make sisx QT_SISX_OPTIONS=-i
+make sis QT_SIS_OPTIONS=-i
//! [30]
diff --git a/doc/src/snippets/code/doc_src_s60-introduction.qdoc b/doc/src/snippets/code/doc_src_s60-introduction.qdoc
index fa9fd45..09ea359 100644
--- a/doc/src/snippets/code/doc_src_s60-introduction.qdoc
+++ b/doc/src/snippets/code/doc_src_s60-introduction.qdoc
@@ -10,19 +10,19 @@
//! [2]
qmake
make debug-winscw release-armv5
- make sisx
+ make sis
//! [2]
//! [3]
- make sisx QT_SISX_TARGET=debug-armv5
+ make sis QT_SIS_TARGET=debug-armv5
//! [3]
//! [4]
- set QT_SISX_TARGET=debug-armv5
- make sisx
+ set QT_SIS_TARGET=debug-armv5
+ make sis
//! [4]
//! [5]
- set QT_SISX_OPTIONS=-i
- make sisx
+ set QT_SIS_OPTIONS=-i
+ make sis
//! [5] \ No newline at end of file
diff --git a/mkspecs/symbian-sbsv2/flm/qt/qmake_store_build.flm b/mkspecs/symbian-sbsv2/flm/qt/qmake_store_build.flm
index 96eb189..0abc7c4 100644
--- a/mkspecs/symbian-sbsv2/flm/qt/qmake_store_build.flm
+++ b/mkspecs/symbian-sbsv2/flm/qt/qmake_store_build.flm
@@ -27,10 +27,10 @@ $(STORE_BUILD_TARGET):
echo "# Name : .make.cache" >> $(CACHE_FILENAME) && \
echo "# Part of : " >> $(CACHE_FILENAME) && \
echo "# Description : This file is used to cache last build target for" >> $(CACHE_FILENAME) && \
- echo "# make sisx target." >> $(CACHE_FILENAME) && \
+ echo "# make sis target." >> $(CACHE_FILENAME) && \
echo "# Version : " >> $(CACHE_FILENAME) && \
echo "# ==============================================================================" >> $(CACHE_FILENAME) && \
- echo QT_SISX_TARGET ?= $(VISUAL_CFG)-$(PLATFORM_PATH) >> $(CACHE_FILENAME) \
+ echo QT_SIS_TARGET ?= $(VISUAL_CFG)-$(PLATFORM_PATH) >> $(CACHE_FILENAME) \
$(call endrule,qmake_store_build)
endef
diff --git a/qmake/generators/symbian/symmake.h b/qmake/generators/symbian/symmake.h
index b0ca5a3..0e5eb14 100644
--- a/qmake/generators/symbian/symmake.h
+++ b/qmake/generators/symbian/symmake.h
@@ -137,7 +137,7 @@ protected:
const QString& itemPrefix,
const QString& itemSuffix);
- void writeSisxTargets(QTextStream &t);
+ void writeSisTargets(QTextStream &t);
void generateDistcleanTargets(QTextStream& t);
// Subclass implements
diff --git a/qmake/generators/symbian/symmake_abld.cpp b/qmake/generators/symbian/symmake_abld.cpp
index 31ef312..bf98079 100644
--- a/qmake/generators/symbian/symmake_abld.cpp
+++ b/qmake/generators/symbian/symmake_abld.cpp
@@ -153,7 +153,7 @@ void SymbianAbldMakefileGenerator::writeMkFile(const QString& wrapperFileName, b
QString makefile(Option::fixPathToTargetOS(fileInfo(wrapperFileName).canonicalFilePath()));
foreach(QString target, wrapperTargets) {
t << target << " : " << makefile << endl;
- t << "\t-$(MAKE) -f \"" << makefile << "\" " << target << " QT_SISX_TARGET=$(VISUAL_CFG)-$(PLATFORM)" << endl << endl;
+ t << "\t-$(MAKE) -f \"" << makefile << "\" " << target << " QT_SIS_TARGET=$(VISUAL_CFG)-$(PLATFORM)" << endl << endl;
}
t << endl;
@@ -361,7 +361,7 @@ void SymbianAbldMakefileGenerator::writeWrapperMakefile(QFile& wrapperFile, bool
writeDeploymentTargets(t);
- writeSisxTargets(t);
+ writeSisTargets(t);
writeStoreBuildTarget(t);
@@ -428,12 +428,12 @@ void SymbianAbldMakefileGenerator::writeStoreBuildTarget(QTextStream &t)
t << "\t@echo # Name : " << MAKE_CACHE_NAME << " >> " MAKE_CACHE_NAME << endl;
t << "\t@echo # Part of : " << project->values("TARGET").join(" ") << " >> " MAKE_CACHE_NAME << endl;
t << "\t@echo # Description : This file is used to cache last build target for >> " MAKE_CACHE_NAME << endl;
- t << "\t@echo # make sisx target. >> " MAKE_CACHE_NAME << endl;
+ t << "\t@echo # make sis target. >> " MAKE_CACHE_NAME << endl;
t << "\t@echo # Version : >> " MAKE_CACHE_NAME << endl;
t << "\t@echo # >> " MAKE_CACHE_NAME << endl;
t << "\t@echo # ============================================================================== >> " MAKE_CACHE_NAME << endl;
t << "\t@echo. >> " MAKE_CACHE_NAME << endl;
- t << "\t@echo QT_SISX_TARGET ?= $(QT_SISX_TARGET) >> " MAKE_CACHE_NAME << endl;
+ t << "\t@echo QT_SIS_TARGET ?= $(QT_SIS_TARGET) >> " MAKE_CACHE_NAME << endl;
t << endl;
generatedFiles << MAKE_CACHE_NAME;
diff --git a/qmake/generators/symbian/symmake_sbsv2.cpp b/qmake/generators/symbian/symmake_sbsv2.cpp
index a76d959..a1381c6 100644
--- a/qmake/generators/symbian/symmake_sbsv2.cpp
+++ b/qmake/generators/symbian/symmake_sbsv2.cpp
@@ -216,7 +216,7 @@ void SymbianSbsv2MakefileGenerator::writeWrapperMakefile(QFile& wrapperFile, boo
qDeleteAll(subtargets);
}
- writeSisxTargets(t);
+ writeSisTargets(t);
generateDistcleanTargets(t);
diff --git a/qmake/generators/symbian/symmake.cpp b/qmake/generators/symbian/symmake.cpp
index 519b2ed..9ddd378 100644
--- a/qmake/generators/symbian/symmake.cpp
+++ b/qmake/generators/symbian/symmake.cpp
@@ -72,10 +72,10 @@
#define MMP_TARGETTYPE "TARGETTYPE"
#define MMP_SECUREID "SECUREID"
-#define SISX_TARGET "sisx"
-#define OK_SISX_TARGET "ok_sisx"
-#define FAIL_SISX_NOPKG_TARGET "fail_sisx_nopkg"
-#define FAIL_SISX_NOCACHE_TARGET "fail_sisx_nocache"
+#define SIS_TARGET "sis"
+#define OK_SIS_TARGET "ok_sis"
+#define FAIL_SIS_NOPKG_TARGET "fail_sis_nopkg"
+#define FAIL_SIS_NOCACHE_TARGET "fail_sis_nocache"
#define RESTORE_BUILD_TARGET "restore_build"
#define PRINT_FILE_CREATE_ERROR(filename) fprintf(stderr, "Error: Could not create '%s'\n", qPrintable(filename));
@@ -329,7 +329,7 @@ void SymbianMakefileGenerator::generatePkgFile(const QString &iconFile)
t << ":\"Vendor\"" << endl << endl;
}
// PKG pre-rules - these are added before actual file installations i.e. SISX package body
if (rawPkgPreRules.size()) {
t << "; Manual PKG pre-rules from PRO files" << endl;
foreach(QString item, rawPkgPreRules) {
@@ -1632,36 +1632,36 @@ void SymbianMakefileGenerator::removeSpecialCharacters(QString& str)
str.replace(QString(" "), QString("_"));
}
-void SymbianMakefileGenerator::writeSisxTargets(QTextStream &t)
+void SymbianMakefileGenerator::writeSisTargets(QTextStream &t)
{
- t << SISX_TARGET ": " RESTORE_BUILD_TARGET << endl;
- QString sisxcommand = QString("\t$(if $(wildcard %1_template.%2),$(if $(wildcard %3)," \
+ t << SIS_TARGET ": " RESTORE_BUILD_TARGET << endl;
+ QString siscommand = QString("\t$(if $(wildcard %1_template.%2),$(if $(wildcard %3)," \
"$(MAKE) -s -f $(MAKEFILE) %4,$(MAKE) -s -f $(MAKEFILE) %5)," \
"$(MAKE) -s -f $(MAKEFILE) %6)")
.arg(fixedTarget)
.arg("pkg")
.arg(MAKE_CACHE_NAME)
- .arg(OK_SISX_TARGET)
- .arg(FAIL_SISX_NOCACHE_TARGET)
- .arg(FAIL_SISX_NOPKG_TARGET);
- t << sisxcommand << endl;
+ .arg(OK_SIS_TARGET)
+ .arg(FAIL_SIS_NOCACHE_TARGET)
+ .arg(FAIL_SIS_NOPKG_TARGET);
+ t << siscommand << endl;
t << endl;
- t << OK_SISX_TARGET ":" << endl;
+ t << OK_SIS_TARGET ":" << endl;
- QString pkgcommand = QString("\tcreatepackage.bat $(QT_SISX_OPTIONS) %1_template.%2 $(QT_SISX_TARGET) " \
- "$(QT_SISX_CERTIFICATE) $(QT_SISX_KEY) $(QT_SISX_PASSPHRASE)")
+ QString pkgcommand = QString("\tcreatepackage.bat $(QT_SIS_OPTIONS) %1_template.%2 $(QT_SIS_TARGET) " \
+ "$(QT_SIS_CERTIFICATE) $(QT_SIS_KEY) $(QT_SIS_PASSPHRASE)")
.arg(fixedTarget)
.arg("pkg");
t << pkgcommand << endl;
t << endl;
- t << FAIL_SISX_NOPKG_TARGET ":" << endl;
- t << "\t$(error PKG file does not exist, 'SISX' target is only supported for executables or projects with DEPLOYMENT statement)" << endl;
+ t << FAIL_SIS_NOPKG_TARGET ":" << endl;
+ t << "\t$(error PKG file does not exist, 'SIS' target is only supported for executables or projects with DEPLOYMENT statement)" << endl;
t << endl;
- t << FAIL_SISX_NOCACHE_TARGET ":" << endl;
- t << "\t$(error Project has to be build before calling 'SISX' target)" << endl;
+ t << FAIL_SIS_NOCACHE_TARGET ":" << endl;
+ t << "\t$(error Project has to be build before calling 'SIS' target)" << endl;
t << endl;
@@ -329,7 +329,7 @@ void SymbianMakefileGenerator::generatePkgFile(const QString &iconFile)
t << ":\"Vendor\"" << endl << endl;
}
- // PKG pre-rules - these are added before actual file installations i.e. SISX package body
+ // PKG pre-rules - these are added before actual file installations i.e. SIS package body
if (rawPkgPreRules.size()) {
t << "; Manual PKG pre-rules from PRO files" << endl;